FynoInApp class

Constructors

FynoInApp()

Properties

fynoInAppState FynoInAppState
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onListUpdate ↔ dynamic Function(dynamic data)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ Socket?
getter/setter pair
stateUpdate Function
getter/setter pair

Methods

deleteAllMessages() Future<void>
deleteMessage(dynamic notification) Future<void>
fynoInAppSocketConnect(dynamic workspaceId, dynamic integrationId, dynamic userId, dynamic origin, dynamic signature) → void
getFynoNotificationIconButton(BuildContext context, Color color, {IconData? notificationIcon, ThemeConfig? themeConfig}) FynoNotificationIcon
loadMoreNotifications(String type, int page) Future<void>
markAllAsRead() Future<void>
markAsRead(dynamic notification) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
resetDefaults() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited